@@ -2,7 +2,7 @@
 """
 @Author: ChenCheng
 @Date: 2022-03-18 10:12:12
-@LastEditTime: 2022-07-13 11:27:38
+@LastEditTime: 2022-07-21 10:50:43
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -77,7 +77,7 @@ class InitLaunchGoodsCallBackHandler(SevenBaseHandler):
             if close_goods_id != "":
                 close_goods_id_list = list(set(close_goods_id.split(",")))
                 close_goods_id_str_list = ','.join(["'%s'" % str(item) for item in close_goods_id_list])
-                LaunchGoodsModel(context=self).update_table("is_launch=0,launch_date=%s", "act_id=%s and " + f"goods_id in ({close_goods_id_str_list})", params=[TimeHelper.get_now_format_time(), act_id])
+                LaunchGoodsModel(context=self).update_table("is_launch=0,launch_date=%s", "act_id=%s and " + f"goods_id in ({close_goods_id_str_list})", params=[self.get_now_datetime(), act_id])
 
             tb_launch_plan = None
             if call_back_info != "":
@@ -259,7 +259,7 @@ class AsyncLaunchGoodsHandler(TopBaseHandler):
             invoke_result_data["error_code"] = "error"
             invoke_result_data["error_message"] = "活动不存在"
             return invoke_result_data
-        launch_goods_model = LaunchGoodsModel(context=self.context)
+        launch_goods_model = LaunchGoodsModel(context=self)
         launch_goods_list = launch_goods_model.get_list("app_id=%s and act_id=%s and is_sync=0 and is_launch=1", params=[app_id,act_id])
         no_launch_goods_list = launch_goods_model.get_list("app_id=%s and act_id=%s and is_sync=0 and is_launch=0", params=[app_id,act_id])
         # 同步不投放的商品
@@ -466,7 +466,8 @@ class CanLaunchGoodsListHandler(TopBaseHandler):
 
         resp = self.get_goods_list(page_index, page_size, goods_name, order_tag, order_by, access_token)
         goods_id_list = [str(goods["num_iid"]) for goods in resp["items_onsale_get_response"]["items"]["item"]]
-        goods_id_in_condition = SevenHelper.get_condition_by_str_list("goods_id", goods_id_list)
+        goods_id_str_list = ','.join(["'%s'" % str(item) for item in goods_id_list])
+        goods_id_in_condition = f"goods_id in ({goods_id_str_list})"
         launch_goods_model = LaunchGoodsModel(context=self)
         launch_goods_list = launch_goods_model.get_list(goods_id_in_condition)
         act_id_list = [launch_goods.act_id for launch_goods in launch_goods_list]
