@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-06-02 11:08:39
-@LastEditTime: 2022-03-02 15:22:14
+@LastEditTime: 2022-05-05 18:04:54
 @LastEditors: HuangJianYi
 :description: 订单相关
 """
@@ -327,7 +327,7 @@ class PrizeOrderExportHandler(SevenBaseHandler):
                         if str(prize_order["create_date"]) == "1900-01-01 00:00:00":
                             data_row["下单时间"] = ""
                         else:
-                            data_row["下单时间"] = str(prize_order["deliver_date"])
+                            data_row["下单时间"] = str(prize_order["create_date"])
                         data_row["订单状态"] = self.get_status_name(prize_order["order_status"])
                         data_row["奖品价值"] = str(prize_roster["prize_price"])
                         data_row["奖品规格"] = prize_roster["properties_name"]
@@ -337,8 +337,8 @@ class PrizeOrderExportHandler(SevenBaseHandler):
 
             resource_path = ""
             if result_data:
-                # if not os.path.exists("temp"):
-                #     os.makedirs("temp")
+                if not os.path.exists("temp"):
+                    os.makedirs("temp")
                 path = "temp/" + UUIDHelper.get_uuid() + ".xlsx"
                 ExcelHelper.export(result_data, path)
 
@@ -438,7 +438,7 @@ class PrizeRosterListExportHandler(SevenBaseHandler):
         prize_roster_model = PrizeRosterModel(context=self)
 
         if export_type == 1:
-            
+
             #奖品订单
             prize_roster_list, total = PrizeRosterModel(context=self).get_dict_page_list("*", page_index, page_size, condition, order_by="id desc", params=params)
             #订单奖品
@@ -461,6 +461,8 @@ class PrizeRosterListExportHandler(SevenBaseHandler):
                 result_data.append(data_row)
             resource_path = ""
             if result_data:
+                if not os.path.exists("temp"):
+                    os.makedirs("temp")
                 path = "temp/" + UUIDHelper.get_uuid() + ".xlsx"
                 ExcelHelper.export(result_data, path)
                 resource_path = OSS2Helper().upload("", path, config.get_value("oss_folder"), False)
